---
title: <span class="badge object-type-scalar"></span> CzechKoruna
---
# <span class="badge object-type-scalar"></span> CzechKoruna

Currency: Czech koruna (czk)

## Definition

```python
# Currency: Czech koruna (czk)
CzechKoruna: typing.Literal["currencyCZK"] = "currencyCZK"
```
